@@ -3,8 +3,12 @@
 import sys
 import re
 import logging
-from pdb import set_trace
-from pdb import post_mortem
+try:
+    from ipdb import set_trace
+    from ipdb import post_mortem
+except:
+    from pdb import set_trace
+    from pdb import post_mortem
 
 logger = logging.getLogger('Products.PDBDebugMode')
 
@@ -17,6 +21,11 @@ ignore_matchers = (
     re.compile(
         '^uncatalogObject unsuccessfully attempted to uncatalog an '
         'object with a uid of ').search,
+    # Ignore broken GenericSetup handlers
+    re.compile(
+        '^Step .* has an invalid import handler$').search,
+    re.compile(
+        '^Step .* has an invalid export handler$').search,
     )
 
 def error(self, msg, *args, **kw):
